"""
Dependencies for the Enkrypt Secure MCP Gateway package.
"""

# NOTE: Also change these in dependencies.py, pyproject.toml, and setup.py
__dependencies__ = [
    "flask>=2.0.0",
    "flask-cors>=3.0.0",
    "redis>=4.0.0",
    "requests>=2.26.0",
    "aiohttp>=3.8.0",
    "python-json-logger>=2.0.0",
    "python-dateutil>=2.8.2",
    "cryptography>=3.4.0",
    "pyjwt>=2.0.0",
    "asyncio>=3.4.3",
    "mcp[cli]"
] 